@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+
 # !/usr/bin/env python
 
 import os
@@ -37,7 +38,7 @@ except ImportError as _e:
     if not os.path.exists(os.path.join(sys.prefix, 'conda-meta')):
         print('Using Anaconda is probably the most reliable method')
     print("E.g. make and use a new environment")
-    print('conda create -n py10side python=3.10 scipy pandas matplotlib')
+    print('conda create -n py10side python=3.10 scipy matplotlib')
     print("then 'pip install PySide6'")
 
     sys.exit(-1)
@@ -112,7 +113,7 @@ class QStatusLogger(logging.Handler):
 class RootListWidget(QListWidget):
     def __init__(self, widget, owner):
         QListWidget.__init__(self, widget)
-        self.setDragDropMode(self.InternalMove)
+        self.setDragDropMode(QAbstractItemView.InternalMove)
         self.setMaximumSize(QSize(16777215, 120 * owner.dpiScale()))
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.setSelectionMode(QAbstractItemView.SingleSelection)
@@ -1044,7 +1045,7 @@ class MainWindow(QMainWindow):
         ini.params['plot_module'] = self.plot_module
         ini.params['script_plot_module'] = self.script_plot_module
         ini.comments['plot_module'] = [
-            "stylw module used by the GUI (e.g. change to getdist.styles.planck, getdist.styles.tab10)"]
+            "style module used by the GUI (e.g. change to getdist.styles.planck, getdist.styles.tab10)"]
         ini.comments['script_plot_module'] = ["module used by saved plot scripts  (e.g. getdist.styles.planck)"]
         self.ConfigDlg = self.ConfigDlg or DialogConfigSettings(self, ini, list(ini.params.keys()), title='Plot Config')
         self.ConfigDlg.show()
@@ -1561,7 +1562,7 @@ class MainWindow(QMainWindow):
             self.warning(caption, type(e).__name__ + ': ' + str(e) + "\n\n" + msg)
             del msg
 
-            if not isinstance(e, GuiSelectionError) and not capture:
+            if not capture:
                 raise
 
     def closePlots(self):
